@@ -1,9 +1,7 @@
-function a() {
-}
+function a() {}
 function foo() {
     function b__2() {
         a__2();
     }
-    function a__2() {
-    }
+    function a__2() {}
 }
